==> haskell-configurator-pg-0.2.7-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.7
visibility:           public
id:                   configurator-pg-0.2.7-A2HBiqHMmpnJ0FTkjARBWA
key:                  configurator-pg-0.2.7-A2HBiqHMmpnJ0FTkjARBWA
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  1e917c0e71295b4b4ced145c6602915f
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/configurator-pg-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/configurator-pg-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.7-A2HBiqHMmpnJ0FTkjARBWA
depends:
    base-4.15.1.0 containers-0.6.4.1
    megaparsec-9.2.2-9J8e8j7w3nJKAXfYAylaYf
    protolude-0.3.2-LjK5I3273sj7mcDH0jeZSp
    scientific-0.3.7.0-1l3L5iYBn9JD8GP8kLjgG7 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.7-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.7
visibility:           public
id:                   configurator-pg-0.2.7-GV8ZufUt1nNLwLE1WqQzdB
key:                  configurator-pg-0.2.7-GV8ZufUt1nNLwLE1WqQzdB
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  bf9ad0ac49056fee64d7fd9af230857b
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/configurator-pg-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/configurator-pg-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.7-GV8ZufUt1nNLwLE1WqQzdB
depends:
    base-4.15.1.0 containers-0.6.4.1
    megaparsec-9.3.1-LmiWZGXQazp1nnuwCBnmcX
    protolude-0.3.3-2V5ngX7wFCtAxkfsFeWf5o
    scientific-0.3.7.0-6CvCEFxXBWR5nYRp7k6pyR text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
